@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  This program is free software which I release under the GNU General Public
@@ -19,6 +19,7 @@
 |  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#include "configure.h"
 
 #include "../src/gkrellm-sysdeps.h"
 
@@ -72,13 +73,13 @@
 
 extern int	errno;
 
-#define DEBUG_SYSDEP	0x1
-#define DEBUG_MAIL		0x10
-#define DEBUG_NET		0x20
-#define DEBUG_TIMER		0x40
-#define DEBUG_SENSORS	0x80
-#define DEBUG_REMOTE	0x100
-#define	DEBUG_BATTERY	0x8000
+#define DEBUG_SYSDEP		0x1
+#define DEBUG_MAIL			0x10
+#define DEBUG_NET			0x20
+#define DEBUG_TIMER			0x40
+#define DEBUG_SENSORS		0x80
+#define DEBUG_NO_LIBSENSORS	0x100
+#define	DEBUG_BATTERY		0x8000
 
 
 #define SENSOR_TEMPERATURE  0
@@ -107,6 +108,8 @@ struct GkrellmdConfig
 				nfs_interval,
 				inet_interval;
 
+	gboolean	without_libsensors;
+
 	gboolean	list_plugins,
 				log_plugins;
 	gchar		*command_line_plugin;
@@ -141,5 +144,4 @@ gint			gkrellmd_update_monitors(void);
 void			gkrellmd_serve_setup(GkrellmdClient *client);
 
 GkrellmdMonitor *gkrellmd_init_mail_monitor(void);
-void			gkrellmd_add_mailbox(gchar *);
 
