@@ -679,6 +679,11 @@ get_args(gint argc, gchar **argv)
 			_GK.log_plugins = TRUE;
 			continue;
 			}
+		if (!strcmp(opt, "without-libsensors"))
+			{
+			_GK.without_libsensors = TRUE;
+			continue;
+			}
 		else if (!strcmp(opt, "help") || !strcmp(opt, "h"))
 			{
 			usage();
