@@ -725,8 +725,12 @@ void
 gkrellm_alert_get_alert_state(GkrellmAlert *alert, gboolean *alarm_state,
 				gboolean *warn_state)
 	{
-	*warn_state = (alert->high.warn_on || alert->low.warn_on);
-	*alarm_state = (alert->high.alarm_on || alert->low.alarm_on);
+	if (!alert)
+		return;
+	if (warn_state)
+		*warn_state = (alert->high.warn_on || alert->low.warn_on);
+	if (alarm_state)
+		*alarm_state = (alert->high.alarm_on || alert->low.alarm_on);
 	}
 
 
