@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  This program is free software which I release under the GNU General Public
@@ -892,7 +892,9 @@ gkrellm_store_chartdata(GkrellmChart *cp, gulong total, ...)
 				else if (N > cd->maxval)
 					cd->maxval = N;
 				}
-			if (N + I > cp->maxval)
+			if (N_discard + I_discard >= cd->maxval)
+				need_scan = TRUE;
+			else if (N + I > cp->maxval)
 				cp->maxval = N + I;
 			}
 		else if (cd->draw_style == CHARTDATA_LINE)
@@ -1959,32 +1961,35 @@ gkrellm_125_sequence(gint value, gboolean use125,
 		return table[0];
 	if (value > table[table_size - 1])
 		return table[table_size - 1];
-	for (i = 0; i < table_size; ++i)
+	if (!snap_to_table && !roundup)
 		{
+		for (i = 0; i < table_size; ++i)
+			{
 /*printf("  mapping[%d] value=%d table=%d\n", i, value, table[i]); */
-		if (value == table[i])
-			return table[i];
-		else if (value == table[i] - 1)
-			return table[i - 1];
-		else if (value == table[i] + 1)
-			return table[i + 1];
+			if (value == table[i])
+				return table[i];
+			else if (value == table[i] - 1)
+				return table[i - 1];
+			else if (value == table[i] + 1)
+				return table[i + 1];
+			}
 		}
-	if (snap_to_table && !roundup)
+	else if (snap_to_table && !roundup)
 		{
 		for (i = table_size - 1; i >= 0; --i)
 			{
-			if (value > table[i])
+			if (value >= table[i])
 				{
 				value = table[i];
 				break;
 				}
 			}
 		}
-	if (snap_to_table && roundup)
+	else if (snap_to_table && roundup)
 		{
 		for (i = 0; i < table_size; ++i)
 			{
-			if (value < table[i])
+			if (value <= table[i])
 				{
 				value = table[i];
 				break;
@@ -2220,6 +2225,7 @@ gkrellm_set_chart_height(GkrellmChart *cp, gint h)
 		cd->data_bitmap = gdk_pixmap_new(top_win->window, cp->w, cp->h, 1);
 		cd->layer.pixmap = gdk_pixmap_new(top_win->window, cp->w, cp->h, -1);
 		}
+	cp->bg_sequence_id += 1;
 	render_chart_pixmaps(cp);
 
 	cf = cp->config;
