@@ -1459,6 +1459,7 @@ typedef struct
 	ClientPlugin;
 
 static GList	*client_plugin_serve_data_list;
+static GList	*plugin_initial_update_list;
 
 static GkrellmFunc
 client_plugin_func(gchar *line)
@@ -1483,6 +1484,30 @@ client_plugin_func(gchar *line)
 	return func;
 	}
 
+static void
+client_plugin_initial_update(ClientPlugin *plug)
+	{
+	GList	*list;
+	void	(*func)(gchar *);
+	gchar	*line, *serve_name;
+
+	func = NULL;
+	serve_name = g_strdup_printf("<%s>", plug->key_name);
+	for (list = plugin_initial_update_list; list; list = list->next)
+		{
+		line = (gchar *) list->data;
+		if (*line == '<')
+			{
+			func = NULL;
+			if (!strcmp(line, serve_name))
+				func = plug->func_cb;
+			}
+		else if (func)
+			(*func)(line);
+		}	
+	g_free(serve_name);
+	}
+
 void
 gkrellm_client_plugin_serve_data_connect(GkrellmMonitor *mon,
 			gchar *key_name, void (*func_cb)(gchar *line))
@@ -1497,6 +1522,8 @@ gkrellm_client_plugin_serve_data_connect(GkrellmMonitor *mon,
 	plug->func_cb = func_cb;
 	client_plugin_serve_data_list
 				= g_list_append(client_plugin_serve_data_list, plug);
+
+	client_plugin_initial_update(plug);
 	}
 
 static gboolean
@@ -1637,6 +1664,9 @@ process_server_line(KeyTable *table, gint table_size, gchar *line)
 		}
 	else if (func)
 		(*func)(line);
+	if (!func && !setup_done)
+		plugin_initial_update_list
+				= g_list_append(plugin_initial_update_list, g_strdup(line));
 	}
 
 
