@@ -1082,13 +1082,14 @@ load_from_piximage_list(gchar *name, GList *image_list,
 				gint index, gchar *subdir)
 	{
 	GList			*list;
-	GkrellmPiximage	**im;
+	GkrellmPiximage	*im;
 
 	list = g_list_nth(image_list, index);
 	if (list)
 		{
-		im = (GkrellmPiximage **) (&list->data);
-		gkrellm_load_piximage(name, NULL, im, subdir);
+		im = (GkrellmPiximage *) list->data;
+		gkrellm_load_piximage(name, NULL, &im, subdir);
+		list->data = (gpointer) im;
 		}
 	else
 		printf("Bad index %d for image list (meter/panel problem?)\n", index);
@@ -1204,7 +1205,7 @@ lookup_piximage_from_name(GList *image_list, gchar *name)
 static void
 load_piximage_table(ImageTable *ti, gint n_piximages, gchar *subdir)
 	{
-	GkrellmPiximage	**im;
+	GkrellmPiximage	*im;
 	GList			*list;
 	gint			i;
 
@@ -1217,8 +1218,9 @@ load_piximage_table(ImageTable *ti, gint n_piximages, gchar *subdir)
 							ti->name_in_list);
 			if (list)
 				{
-				im = (GkrellmPiximage **) (&list->data);
-				gkrellm_load_piximage(ti->name, ti->xpm, im, subdir);
+				im = (GkrellmPiximage *) list->data;
+				gkrellm_load_piximage(ti->name, ti->xpm, &im, subdir);
+				list->data = (gpointer) im;
 				}
 			}
 		else
@@ -1261,8 +1263,14 @@ destroy_piximage(GkrellmPiximage **im)
 static void
 destroy_piximage_list(GList *list, GList *name_list, gchar *debug_name)
 	{
+	GkrellmPiximage *im;
+
 	for ( ; list; list = list->next, name_list = name_list->next)
-		destroy_piximage((GkrellmPiximage **) (&list->data));
+		{
+		im = (GkrellmPiximage *) list->data;
+		destroy_piximage(&im);
+		list->data = NULL;
+		}
 	}
 
 static void
