@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  This program is free software which I release under the GNU General Public
@@ -424,7 +424,7 @@ draw_disk_extra(DiskMon *disk)
 	{
 	gchar	buf[128];
 
-	if (!disk->extra_info)
+	if (!disk->chart || !disk->extra_info)
 		return;
 	format_disk_data(disk, text_format_locale, buf, sizeof(buf));
 	if (!disk->new_text_format)
@@ -437,7 +437,8 @@ static void
 cb_command_process(GkrellmAlert *alert, gchar *src, gchar *dst, gint len,
 			DiskMon *disk)
 	{
-	format_disk_data(disk, src, dst, len);
+	if (disk->chart)
+		format_disk_data(disk, src, dst, len);
 	}
 
 static void
