@@ -308,3 +308,7 @@ gboolean	gkrellm_sys_sensors_mbmon_supported(void);
 gboolean	gkrellm_sys_sensors_mbmon_check(gboolean force);
 gboolean	gkrellm_sys_sensors_mbmon_get_value(gchar *name, gfloat *value);
 gboolean	gkrellm_sys_sensors_mbmon_port_change(gint port);
+
+  /* Config migration helper */
+void	gkrellm_sensors_config_migrate_connect(
+				gboolean (*config_migrate_func)(), gint sysdep_private);
