@@ -706,7 +706,7 @@ gkrellm_gtk_category_vbox(GtkWidget *box, gchar *category_header,
 	label = gtk_label_new("    ");
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	vbox1 = gtk_vbox_new(FALSE, box_pad);
-	gtk_box_pack_start(GTK_BOX(hbox), vbox1, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), vbox1, TRUE, TRUE, 0);
 
 	/* Add some bottom pad */
 	label = gtk_label_new("");
