@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  This program is free software which I release under the GNU General Public
@@ -760,6 +760,8 @@ side_frame_button_press(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 			gtk_widget_show(gtree.middle_vbox);
 			gtk_widget_show(gtree.top0_vbox);
 			gtk_widget_show(gtree.bottom_vbox);
+			while (gtk_events_pending())
+				gtk_main_iteration ();
 			if (direction == CLOSE_RIGHT)
 				gdk_window_move(gtree.window->window,
 								x_gkrell - _GK.chart_width, y_gkrell);
@@ -769,6 +771,8 @@ side_frame_button_press(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 			gtk_widget_hide(gtree.top0_vbox);
 			gtk_widget_hide(gtree.bottom_vbox);
 			gtk_widget_hide(gtree.middle_vbox);
+			while (gtk_events_pending())
+				gtk_main_iteration ();
 			if (direction == CLOSE_RIGHT)
 				gdk_window_move(gtree.window->window,
 								x_gkrell + _GK.chart_width, y_gkrell);
@@ -2026,28 +2030,11 @@ setup_signal_handler(void)
 	}
 
 
-#if defined(WIN32) && defined(_WINDOWS)
-int APIENTRY WinMain(HINSTANCE	hInstance,
-					HINSTANCE	hPrevInstance,
-					LPSTR		lpCmdLine,
-					int			nCmdShow)
-	{
-	int		argc;
-	gint	i;
-	gchar	*s, *sm;
-	gchar	**argv;
-	gchar	*cmd;
-
-	// need to get exe too
-	cmd = GetCommandLine();
-	g_shell_parse_argv(cmd, &argc, &argv, NULL);
-#else
 gint
 main(gint argc, gchar **argv)
 	{
 	gint		i;
 	gchar		*s;
-#endif
 
 	gkrellm_sys_main_init();
 
@@ -2135,6 +2122,8 @@ main(gint argc, gchar **argv)
 			}
 		else if (!strcmp(s, "nolock"))
 			_GK.nolock = TRUE;
+		else if (!strcmp(s, "without-libsensors"))
+			_GK.without_libsensors = TRUE;
 		else if (!strcmp(s, "demo"))
 			++_GK.demo;
 		else if (!strcmp(s, "test"))
@@ -2246,9 +2235,29 @@ main(gint argc, gchar **argv)
 	gkrellm_save_all();
 	gkrellm_exit(0);
 
-#if defined(_WINDOWS)
-    g_strfreev(argv);
-#endif
-
 	return 0;
 	}
+
+
+#if defined(WIN32) && defined(_WINDOWS)
+int APIENTRY WinMain(HINSTANCE	hInstance,
+					HINSTANCE	hPrevInstance,
+					LPSTR		lpCmdLine,
+					int			nCmdShow)
+	{
+	int		argc;
+	gint	i, ret;
+	gchar	*s, *sm;
+	gchar	**argv;
+	gchar	*cmd;
+
+	// need to get exe too
+	cmd = GetCommandLine();
+	g_shell_parse_argv(cmd, &argc, &argv, NULL);
+
+	ret = main(argc, argv);
+    g_strfreev(argv);
+	return ret;
+	}
+#endif
+
