@@ -90,7 +90,12 @@ static gboolean	(*get_voltage)(gchar *name, gint id,
 			gint iodev, gint inter, gfloat *v);
 
 static void read_sensors_config(void);
+static gboolean	(*config_migrate)(gchar *current_name, gchar *config_name,
+					gint current, gint config);
 
+static gint		sensor_config_version;
+static gint		sensor_current_sysdep_private;
+static gint		sensor_config_sysdep_private;
 
 void
 gkrellm_sensors_client_divert(gboolean (*get_temp_func)(),
@@ -101,6 +106,13 @@ gkrellm_sensors_client_divert(gboolean (*get_temp_func)(),
 	get_voltage = get_volt_func;
 	}
 
+void
+gkrellm_sensors_config_migrate_connect(gboolean (*migrate_func)(),
+			gint sysdep_private)
+	{
+	config_migrate = migrate_func;
+	sensor_current_sysdep_private = sysdep_private;
+	}
 
 static gboolean
 setup_sensor_interface(void)
@@ -150,7 +162,9 @@ gkrellm_sensors_add_sensor(gint type, gchar *sensor_path, gchar *id_name,
 				&sensor->name_locale);
 	sensor->default_label = g_strdup(default_label);
 
-	sensor->default_factor = sensor->factor = factor;
+	sensor->default_factor = factor;
+	sensor->factor
+			= (sensor->default_factor > 0.0 ? sensor->default_factor : 1.0);
 	sensor->default_offset = sensor->offset = offset;
 	sensor->type = type;
 	sensor->id = id;
@@ -232,38 +246,6 @@ append_sensor_to_order_list(Sensor *sr)
 		volt_order_list = g_list_append(volt_order_list, sr);
 	}
 
-  /* Remove embedded "-i2c-" or "-isa-" from lm_sensors chip names so
-  |  there can be a chance for config name sysfs compatibility.  This function
-  |  here in sensors.c is a kludge.  Give user configs a chance to get
-  |  converted and then move this function to sysdeps/linux.c where it
-  |  belongs.
-  |  Munge names like w83627hf-isa-0290 to w83627hf-0-0290
-  |                or w83627hf-i2c-0-0290 to w83627hf-0-0290
-  |  lm_sensor i2c bus address may not be 4 digits, eg: w83782d-i2c-0-2d
-  |  and for that we want: w83782d-0-002d
-  */
-void
-gkrellm_sensors_linux_name_fix(gchar *id_name)
-	{
-#if defined(__linux__)
-	gchar	*s;
-	gint	len, bus = 0;
-	guint	addr = 0;
-
-	len = strlen(id_name) + 1;
-	if ((s = strstr(id_name, "-i2c-")) != NULL)
-		{
-		sscanf(s + 5, "%d-%x", &bus, &addr);
-		snprintf(s, len - (s - id_name), "-%d-%04x", bus, addr);
-		}
-	else if ((s = strstr(id_name, "-isa-")) != NULL)
-		{
-		*(s + 1) = '0';
-		memmove(s + 2, s + 4, strlen(s + 4) + 1);
-		}
-#endif
-	}
-
 
   /* This is called as sensors are read from the config and I will want to
   |  re-order the sensors_list to reflect the config order. Re-ordering is
@@ -277,11 +259,18 @@ map_sensor_label(gchar *label, gchar *name)
 	GList		*list;
 	Sensor		*sr;
 
-	gkrellm_sensors_linux_name_fix(name);		/* XXX temporary, remove me */
 	for (list = sensor_list; list; list = list->next)
 		{
 		sr = (Sensor *) list->data;
-		if (!sr->has_config && !strcmp(sr->id_name, name))
+		if (   !sr->has_config
+		    && (   !strcmp(sr->id_name, name)
+		        || (   config_migrate
+		            && (*config_migrate)(sr->id_name, name,
+							sensor_current_sysdep_private,
+							sensor_config_sysdep_private)
+		           )
+		       )
+		   )
 			{
 			gkrellm_locale_dup_string(&sr->name, label, &sr->name_locale);
 			append_sensor_to_order_list(sr);
@@ -389,11 +378,16 @@ lookup_sensor_from_id_name(gchar *name)
 
 	if (!name)
 		return NULL;
-	gkrellm_sensors_linux_name_fix(name);		/* XXX temporary, remove me */
 	for (list = sensor_list; list; list = list->next)
 		{
 		s = (Sensor *) list->data;
-		if (!strcmp(s->id_name, name))
+		if (   !strcmp(s->id_name, name)
+		    || (   config_migrate
+		        && (*config_migrate)(s->id_name, name,
+							sensor_current_sysdep_private,
+							sensor_config_sysdep_private)
+		       )
+		   )
 			return s;
 		}
 	return NULL;
@@ -686,8 +680,6 @@ static gint		minus_width;		/* If will be drawing neg voltages */
 static gint		pixel_grub;
 
 
-static gint		sensor_config_version;
-
   /* Avoid writing decimal values into the config to avoid possible
   |  locale changing decimal point breakage (decimal point can be '.' or ',')
   */
@@ -1642,17 +1634,17 @@ gkrellm_init_sensor_monitor(void)
   /* Don't use the user-config.  Save into sensors-config and only if there
   |  is a sensor_list.  This preserves configs across a possible sensors
   |  modules load screw up.
-  */
-  /* 2.1.15 scales sensor factor/offset values by SENSOR_FLOAT_FACTOR to avoid
+  |
+  |  2.2.3 sets sensor_config_version to 1 to allow sensor relocation
+  |  to composite CPU on a SMP machine.
+  |
+  |  2.1.15 scales sensor factor/offset values by SENSOR_FLOAT_FACTOR to avoid
   |  writting decimal points in the config.  This is not backwards compatible
   |  with the pre 2.1.15 sensor_config format hence the config file name
   |  change to sensor-config.  But sensor_config is forward compatible
   |  since the float factor defaults to 1.0.
   */
-  /* gkrellm 2.2.3 sets sensor_config_version to 1 to allow sensor relocation
-  |  to composite CPU on a SMP machine.
-  */
-#define	SENSOR_CONFIG_VERSION		1
+#define	SENSOR_CONFIG_VERSION			1
 
 #define	SENSOR_CONFIG_KEYWORD		"sensor"
 #define	SENSOR_CONFIG_FILE			"sensor-config"
@@ -1690,6 +1682,7 @@ save_sensors_config(FILE *f_not_used)
 	GList	*list;
 	Sensor	*s;
 	gchar	*config, quoted_name[128], buf[128];
+	gfloat	factor, offset;
 
 	if (!sensor_list)
 		return;
@@ -1702,6 +1695,8 @@ save_sensors_config(FILE *f_not_used)
 
 	fprintf(f, "%s sensor_config_version %d\n",
 				SENSOR_CONFIG_KEYWORD, SENSOR_CONFIG_VERSION);
+	fprintf(f, "%s sensor_sysdep_private %d\n",
+				SENSOR_CONFIG_KEYWORD, sensor_current_sysdep_private);
 	fprintf(f, "%s sensor_float_factor %.0f\n",
 				SENSOR_CONFIG_KEYWORD, SENSOR_FLOAT_FACTOR);
 	fprintf(f, "%s gkrellm_float_factor %.0f\n",
@@ -1712,11 +1707,13 @@ save_sensors_config(FILE *f_not_used)
 		if (s->name && *(s->name))
 			{
 			snprintf(quoted_name, sizeof(quoted_name), "\"%s\"", s->id_name);
+			factor = (s->default_factor > 0.0 ? s->factor : 0.0);
+			offset = (s->default_factor > 0.0 ? s->offset : 0.0);
 			fprintf(f, "%s \"%s\" %s %.0f %.0f %d %d\n",
 				SENSOR_CONFIG_KEYWORD,
 				s->name, quoted_name,
-				s->factor * SENSOR_FLOAT_FACTOR,
-				s->offset * SENSOR_FLOAT_FACTOR,
+				factor * SENSOR_FLOAT_FACTOR,
+				offset * SENSOR_FLOAT_FACTOR,
 				s->enabled, s->location);
 			if (s->alert)
 				gkrellm_save_alertconfig(f, s->alert,
@@ -1760,6 +1757,8 @@ load_sensors_config(gchar *arg)
 		printf("load_sensors_config: <%s> <%s>\n", config, item);
 	if (!strcmp(config, "sensor_config_version"))
 		sscanf(item, "%d", &sensor_config_version);
+	else if (!strcmp(config, "sensor_sysdep_private"))
+		sscanf(item, "%d", &sensor_config_sysdep_private);
 	else if (!strcmp(config, "units_fahrenheit"))
 		sscanf(item, "%d", &units_fahrenheit);
 	else if (!strcmp(config, "volt_display_mode"))
@@ -1798,8 +1797,11 @@ load_sensors_config(gchar *arg)
 			 && (s = map_sensor_label(label, id_name)) != NULL
 			)
 		{
-		s->factor = f / sensor_float_factor;
-		s->offset = o / sensor_float_factor;
+		if (f > 0.0 && s->default_factor > 0.0)
+			{
+			s->factor = f / sensor_float_factor;
+			s->offset = o / sensor_float_factor;
+			}
 		s->enabled = e;
 
 		if (s->type == SENSOR_VOLTAGE)
@@ -2333,6 +2335,10 @@ set_sensor_widget_states(Sensor *s)
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(offset_spin_button), offset);
 	gtk_widget_set_sensitive(optionmenu, p_sensitive);
 	gtk_widget_set_sensitive(alert_button, f_sensitive);
+
+	if (s && s->default_factor == 0.0)
+		f_sensitive = o_sensitive = FALSE;
+
 	gtk_widget_set_sensitive(factor_spin_button, f_sensitive);
 	gtk_widget_set_sensitive(offset_spin_button, o_sensitive);
 	}
