@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2004 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  FreeBSD code: Hajimu UMEMOTO <ume@FreeBSD.org>
@@ -355,7 +355,7 @@ gkrellm_sys_disk_read_data(void)
 		     ndevs * sizeof(long)) == ndevs * sizeof(long))
 		{
 		for (dn = 0; dn < ndevs; ++dn)
-			gkrellm_disk_assign_data_nth(dn, 0, cur_dk_xfer[dn]);
+			gkrellm_disk_assign_data_nth(dn, 0, cur_dk_xfer[dn], FALSE);
 		}
 	free(cur_dk_xfer);
 	}
@@ -422,7 +422,7 @@ gkrellm_sys_disk_read_data(void)
 			snprintf(name, sizeof(name), "%s%d", dev->device_name,
 					dev->unit_number);
 			gkrellm_disk_assign_data_by_name(name,
-					dev->bytes_read, dev->bytes_written);
+					dev->bytes_read, dev->bytes_written, FALSE);
 			}
 		free(dev_select);
 		}
@@ -1346,6 +1346,12 @@ gkrellm_sys_sensors_get_temperature(gchar *path, gint id,
 	{
 	u_char byte;
 
+	if (interface == MBMON_INTERFACE)
+		{
+		gkrellm_sys_sensors_mbmon_check(FALSE);
+		return gkrellm_sys_sensors_mbmon_get_value(path, temp);
+		}
+
 	if (interface == INTERFACE_ACPI)
 		{
 		int value;
@@ -1372,6 +1378,12 @@ gkrellm_sys_sensors_get_fan(gchar *path, gint id,
 	{
 	u_char byte;
 
+	if (interface == MBMON_INTERFACE)
+		{
+		gkrellm_sys_sensors_mbmon_check(FALSE);
+		return gkrellm_sys_sensors_mbmon_get_value(path, fan);
+		}
+
 	if (get_data(iodev, LM78_FAN(id), interface, &byte))
 		{
 		if (byte == 0)
@@ -1389,6 +1401,12 @@ gkrellm_sys_sensors_get_voltage(gchar *path, gint id,
 	{
 	u_char byte;
 
+	if (interface == MBMON_INTERFACE)
+		{
+		gkrellm_sys_sensors_mbmon_check(FALSE);
+		return gkrellm_sys_sensors_mbmon_get_value(path, volt);
+		}
+
 	if (get_data(iodev, LM78_VOLT(id), interface, &byte))
 		{
 		if (volt)
@@ -1418,10 +1436,13 @@ gkrellm_sys_sensors_init(void)
 	gint		interface, id;
 	int		oid_acpi_temp[CTL_MAXNAME + 2];
 	size_t		oid_acpi_temp_len = sizeof(oid_acpi_temp);
-	gboolean	found_sensors = FALSE, found_acpi_sensors = FALSE;
 	GList		*list;
 	struct freebsd_sensor *sensor;
 
+	/* Do intial daemon reads to get sensors loaded into sensors.c
+	*/
+	gkrellm_sys_sensors_mbmon_check(TRUE);
+
 	for (id = 0;;)
 	{
 		snprintf(mib_name, sizeof(mib_name),
@@ -1437,7 +1458,6 @@ gkrellm_sys_sensors_init(void)
 		gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE, NULL,
 					   mib_name, 0, 0,
 					   interface, 1.0, 0.0, NULL, label);
-		found_acpi_sensors = TRUE;
 	}
 
 	if (freebsd_sensor_list)
@@ -1451,10 +1471,9 @@ gkrellm_sys_sensors_init(void)
 					sensor->factor, sensor->offset,
 					NULL, sensor->default_label);
 			}
-		found_sensors = TRUE;
 		}
 
-	return (found_sensors || found_acpi_sensors);
+	return (TRUE);
 	}
 
 static gboolean
