@@ -23,6 +23,7 @@
 #include <locale.h>
 #include <sys/types.h>
 #include <dirent.h>
+#include <string.h>
 
 
 static gboolean		need_locale_fix,
@@ -31,6 +32,7 @@ static gboolean		need_locale_fix,
 					have_sysfs,
 					have_sysfs_stats,
 					have_sysfs_sensors;
+
 static gchar		locale_decimal_point;
 
 
@@ -1888,16 +1890,19 @@ gkrellm_sys_uptime_init(void)
 #define	THERMAL_DIR			"/proc/acpi/thermal"
 #define	SENSORS_DIR			"/proc/sys/dev/sensors"
 #define SYSFS_I2C_DIR		"/sys/bus/i2c/devices"
-#define UNINORTH_DIR       "/sys/devices/temperatures"
+#define SYSFS_HWMON_DIR		"/sys/class/hwmon"
+#define UNINORTH_DIR		"/sys/devices/temperatures"
+#define WINDFARM_DIR		"/sys/devices/platform/windfarm.%d"
 
   /* mbmon and hddtemp sensor interfaces are handled in sensors-common.c
   */
-#define	LM_SENSOR_INTERFACE			0
-#define	THERMAL_INTERFACE			1
-#define	THERMAL_ZONE_INTERFACE		2
-#define	NVIDIA_SETTINGS_INTERFACE	3
-#define IBM_ACPI_INTERFACE		4
-#define UNINORTH_INTERFACE    5
+#define	LIBSENSORS_INTERFACE		1
+#define	THERMAL_INTERFACE			2
+#define	THERMAL_ZONE_INTERFACE		3
+#define	NVIDIA_SETTINGS_INTERFACE	4
+#define IBM_ACPI_INTERFACE			5
+#define UNINORTH_INTERFACE			6
+#define WINDFARM_INTERFACE			7
 
 #define IBM_ACPI_FAN_FILE	"/proc/acpi/ibm/fan"
 #define IBM_ACPI_THERMAL	"/proc/acpi/ibm/thermal"
@@ -1909,7 +1914,313 @@ gkrellm_sys_uptime_init(void)
 #define IBM_ACPI_NA1_TEMP        5
 #define IBM_ACPI_BAT2_TEMP       6
 #define IBM_ACPI_NA2_TEMP        7
-#define IBM_ACPI_FAN		 8
+#define IBM_ACPI_FAN			 8
+
+#define	SENSOR_NAMES_I2C			0
+#define	SENSOR_NAMES_HWMON			1
+#define	SENSOR_NAMES_LIBSENSORS		2
+
+  /* 2.2.10 uses libsensors or SYSFS_HWMON_DIR if available,
+  |  so try to save users old sensors-config that used SYSFS_I2C_DIR.
+  */
+typedef struct
+	{
+	gchar	*current_name,
+			*i2c_name,
+			*hwmon_name;
+	}
+	ConfigMap;
+
+GList	*config_map_list;
+
+static gboolean
+sensors_config_migrate(gchar *current_name, gchar *config_name,
+		gint current, gint config)
+	{
+	ConfigMap	*config_map;
+	GList		*list;
+	gchar		*p0, *p1;
+	gint		n;
+
+	/* Migrating to a libsensor name can be based on
+	|  existing detected sysfs names stored in the config_map_list
+	*/
+	if (   (   current == SENSOR_NAMES_LIBSENSORS
+	        && (config == SENSOR_NAMES_I2C || config == SENSOR_NAMES_HWMON)
+	       )
+	    || (current == SENSOR_NAMES_HWMON && config == SENSOR_NAMES_I2C)
+	   )
+		{
+		for (list = config_map_list; list; list = list->next)
+			{
+			config_map = (ConfigMap *) list->data;
+			if (   !strcmp(current_name, config_map->current_name)
+			    && (   (   config_map->i2c_name
+			            && !strcmp(config_name, config_map->i2c_name)
+			           )
+			        || (   config_map->hwmon_name
+			            && !strcmp(config_name, config_map->hwmon_name)
+			           )
+			       )
+			   )
+				{
+				if (_GK.debug_level & DEBUG_SENSORS)
+					{
+					printf("migrate name %s->%s: %s -> %s\n",
+							(config == SENSOR_NAMES_I2C) ? "i2c" : "hwmon",
+							(current == SENSOR_NAMES_LIBSENSORS) ?
+									"libsensors" : "hwmon",
+							config_name, current_name);
+					}
+				return TRUE;
+				}
+			}
+		}
+
+	/* But changing from a libsensor name to a sysfs name can only be guessed
+	|  since libsensors may not be compiled in and so don't have a libsensor
+	|  name to test against.
+	*/
+	if (   (   (current == SENSOR_NAMES_I2C || current == SENSOR_NAMES_HWMON)
+	        && config == SENSOR_NAMES_LIBSENSORS
+	       )
+		/* This case should not happen unless downgrading kernel */
+	    || (current == SENSOR_NAMES_I2C && config == SENSOR_NAMES_HWMON)
+	   )
+		{
+		/* Eg, migrate current sysdep name: w83627ehf-hwmon0/temp1
+		|      from a config sysdep name:   w83627ehf@a10/temp1
+		*/
+		p0 = strchr(current_name, (gint) '-');
+		n = (p0 ? p0 - current_name : -1);
+		if (n > 0 && !strncmp(current_name, config_name, n))
+			{
+			p0 = strrchr(current_name, (gint) '/');
+			p1 = strrchr(config_name, (gint) '/');
+			if (p0 && p1 && !strcmp(p0, p1))
+				{
+				if (_GK.debug_level & DEBUG_SENSORS)
+					{
+					printf("migrate name %s->%s: %s -> %s\n",
+							(config == SENSOR_NAMES_LIBSENSORS) ?
+									"libsensors" : "hwmon",
+							(current == SENSOR_NAMES_I2C) ? "i2c" : "hwmon",
+							config_name, current_name);
+					}
+				return TRUE;
+				}
+			}
+		}
+	return FALSE;
+	}
+
+#ifdef HAVE_LIBSENSORS
+#include <sensors/sensors.h>
+
+static gboolean
+libsensors_init(void)
+	{
+	gint			nr, nr1, nr2, len;
+	const sensors_chip_name		*name;
+	const sensors_feature_data	*feature;
+	gchar			*label, *s;
+	FILE			*f;
+	gchar			id_name[512], sensor_path[512];
+	gint			type, n_sensors_added;
+	ConfigMap		*config_map;
+
+	f = fopen("/etc/sensors.conf", "r");
+	if (!f)
+		{
+		if (_GK.debug_level & DEBUG_SENSORS)
+			printf("libsensors: could not open /etc/sensors.conf\n");
+		return FALSE;
+		}
+
+	if (sensors_init(f) != 0)
+		{
+		if (_GK.debug_level & DEBUG_SENSORS)
+			printf("libsensors: init failed!\n");
+		return FALSE;
+		}
+	fclose(f);
+
+	if (_GK.debug_level & DEBUG_SENSORS)
+		printf("libsensors: init OK\n");
+
+	n_sensors_added = 0;
+	nr = 0;
+	while ((name = sensors_get_detected_chips(&nr)))
+		{
+		nr1 = 0, nr2 = 0;
+		while ((feature = sensors_get_all_features(*name, &nr1, &nr2)))
+			{
+			if (   sensors_get_ignored(*name, feature->number)
+			    && feature->mapping == SENSORS_NO_MAPPING
+			   )
+				{
+				if (name->bus >= 0)
+					snprintf(id_name, sizeof(id_name), "%s@%d:%x/%s",
+						name->prefix, name->bus, name->addr, feature->name);
+				else
+					snprintf(id_name, sizeof(id_name), "%s@%x/%s",
+						name->prefix, name->addr, feature->name);
+				/* We need to store both the prefix and the busname, but we
+				|  only have one string, so concat them together separated by :
+				*/
+				snprintf(sensor_path, sizeof (sensor_path), "%s:%s",
+						name->prefix, name->busname ? name->busname : "NULL");
+
+				if (!strncmp(feature->name, "temp", 4))
+					type = SENSOR_TEMPERATURE;
+				else if (!strncmp(feature->name, "fan", 3))
+					type = SENSOR_FAN;
+				else if (!strncmp(feature->name, "in", 2))
+					type = SENSOR_VOLTAGE;
+				else
+					{
+					if (_GK.debug_level & DEBUG_SENSORS)
+						printf("libsensors: error determining type for: %s\n",
+								id_name);
+					continue;
+					}
+
+				/* failsafe tests, will bus and addr fit in 16 bits (signed)
+				*/
+				if (name->bus != ((name->bus << 16) >> 16))
+					{
+					if (_GK.debug_level & DEBUG_SENSORS)
+						printf("libsensors: bus bigger than 16 bits: %s\n",
+								id_name);
+					continue;
+					}
+				if (name->addr != ((name->addr << 16) >> 16))
+					{
+					if (_GK.debug_level & DEBUG_SENSORS)
+						printf("libsensors: addr bigger than 16 bits: %s\n",
+								id_name);
+					continue;
+					}
+
+				if (sensors_get_label(*name, feature->number, &label) != 0)
+					{
+					if (_GK.debug_level & DEBUG_SENSORS)
+						printf("libsensors: error getting label for: %s\n",
+								id_name);
+					label = NULL;
+					}
+
+				/* Strip some common post/prefixes for smaller default labels
+				*/
+				len = strlen(label);
+				switch (type)
+				  {
+				  case SENSOR_TEMPERATURE:
+					if (len > 5 && !strcasecmp(label + len - 5, " Temp"))
+						label[len - 5] = 0;
+					if (len > 12
+						&& !strcasecmp(label + len - 12, " Temperature"))
+						label[len - 12] = 0;
+					break;
+				  case SENSOR_FAN:
+					if (len > 4 && !strcasecmp(label + len - 4, " Fan"))
+						label[len - 4] = 0;
+					if (len > 10
+						&& !strcasecmp(label + len - 10, " FAN Speed"))
+						label[len - 10] = 0;
+					break;
+				  case SENSOR_VOLTAGE:
+					if (len > 8 && !strcasecmp(label + len - 8, " Voltage"))
+						label[len - 8] = 0;
+					if (!strncmp(label, "ATX ", 4))
+						memmove(label, label + 4, strlen (label + 4) + 1);
+					break;
+				  }
+				/* notice that we store the bus and addr both in iodev as
+				|  2 _signed 16 bit ints.  Default factor of zero tells
+				|  sensor.c that sensor formula is handled, ie via
+				|  /etc/sensors.conf.
+				*/
+				gkrellm_sensors_add_sensor(type, sensor_path, id_name,
+							feature->number,
+							(name->bus & 0xFFFF) | (name->addr << 16),
+							LIBSENSORS_INTERFACE, 0.0, 0.0,
+							NULL, label);
+				++n_sensors_added;
+				if (label)
+					free(label);
+
+				if (_GK.debug_level & DEBUG_SENSORS)
+					printf("%s %s %x\n",
+							sensor_path, id_name,
+							(name->bus & 0xFFFF) | (name->addr << 16));
+
+				if (   name->busname
+				    && (s = strrchr(name->busname, '/')) != NULL
+				    && *(s + 1)
+				   )
+					{
+					config_map = g_new0(ConfigMap, 1);
+					config_map->current_name = g_strdup(id_name);
+					config_map->i2c_name = g_strdup_printf("%s-%s/%s",
+							name->prefix, s + 1, feature->name);
+					config_map->hwmon_name = g_strdup_printf("%s-%s/%s",
+							name->prefix, "hwmon0", feature->name);
+					config_map_list =
+							g_list_append(config_map_list, config_map);
+ 					}
+				}
+			}
+		}
+	return ((n_sensors_added > 0) ? TRUE : FALSE);
+	}
+
+gboolean
+libsensors_get_value(char *sensor_path, int id, int iodev, float *value)
+	{
+	char *p;
+	sensors_chip_name name;
+	double val;
+	int result;
+
+	/* fill name */
+	p = strchr(sensor_path, ':');
+	if (!p)
+		{
+		if (_GK.debug_level & DEBUG_SENSORS)
+			printf("libsensors: error parsing sensor_path: %s\n",
+					sensor_path);
+		return FALSE;
+		}
+	*p = 0;						/* We must undo this !! (or make a copy) */
+	name.prefix = sensor_path;
+	name.bus = (iodev << 16) >> 16;	/* sign extend the low 16 bits */
+	name.addr = iodev >> 16;
+	name.busname = p + 1;
+	if (!strcmp(name.busname, "NULL"))
+		name.busname = NULL;
+
+	result = sensors_get_feature(name, id, &val) == 0;
+
+	if (!result && (_GK.debug_level & DEBUG_SENSORS))
+		{
+		if (name.bus >= 0)
+			printf(
+				"libsensors: error getting value for: %s@%d:%x feature: %d\n",
+				name.prefix, name.bus, name.addr, id);
+		else
+			printf("libsensors: error getting value for: %s@%x feature: %d\n",
+					name.prefix, name.addr, id);
+		}
+
+	if (value)
+		*value = val;
+
+	*p = ':';					/* !!! */
+	return result;
+	}
+
+#endif	/* HAVE_LIBSENSORS */
 
 typedef struct
 	{
@@ -2036,6 +2347,54 @@ static VoltDefault	voltdefault9[] =
 	{ "+3.3V",	1.0,    0, 		NULL }
 	};
 
+	/* abituguru2	*/
+static VoltDefault	voltdefault10[] =
+	{
+	{ "Vcor",	1.0,    0, NULL },
+	{ "DDR",	1.0,    0, NULL },
+	{ "DDR VTT",1.0,    0, NULL },
+	{ "CPU VTT",1.0,    0, NULL },
+	{ "MCH 1.5",1.0,    0, NULL },
+	{ "MCH 2.5",1.0,    0, NULL },
+	{ "ICH",	1.0,    0, NULL },
+	{ "+12V",	1.0,    0, NULL },
+	{ "+12V 4P",1.0,    0, NULL },
+	{ "+5V",	1.0,    0, NULL },
+	{ "+3.3V",	1.0,    0, NULL },
+	{ "5VSB",	1.0,    0, NULL }
+	};
+
+	/* abituguru - Several variations at:
+	|  http://www.lm-sensors.org/wiki/Configurations/Abit
+	*/
+static VoltDefault	voltdefault11[] =
+	{
+	{ "Vcor",	1.0,	0, NULL },
+	{ "DDR",	1.0,	0, NULL },
+	{ "DDR VTT",1.0,	0, NULL },
+	{ "NB",		1.0,	0, NULL },
+	{ "SB",		1.0,	0, NULL },
+	{ "HTT",	1.0,	0, NULL },
+	{ "AGP",	1.0,	0, NULL },
+	{ "+5V",	1.788,	0, NULL },		/* in7 @*1.788	*/
+	{ "+3.3V",	1.248,	0, NULL },		/* in8 @*1.248	*/
+	{ "5VSB",	1.788,	0, NULL },		/* in9 @*1.788	*/
+	{ "3VDual",	1.248,	0, NULL }		/* in10 @*1.248 */
+	};
+
+	/* "w83627thf-*" "w83637hf-*"	*/
+static VoltDefault	voltdefault12[] =
+	{
+	{ "Vcore",	1.0,   0, NULL },
+	{ "+12V",	3.80,  0, NULL },		/* in1 ((28/10)+1)*@		*/
+	{ "+3.3V",	1.0,   0, NULL },
+	{ "+5V",	1.67,  0, NULL },		/* in3 ((34/51)+1)*@		*/
+	{ "-12V",	5.14 , -14.91, NULL },	/* in4 (5.14 * @) - 14.91	*/
+	{ "unused",	1.0,   0, NULL },
+	{ "unused",	1.0,   0, NULL },
+	{ "V5SB",	1.68,  0, NULL },		/* in7 ((6.8/10)+1)*@		*/
+	{ "VBat",	1.0,   0, NULL }		/* in8 ((6.8/10)+1)*@		*/
+	};
 
 
 gboolean
@@ -2045,7 +2404,7 @@ gkrellm_sys_sensors_get_temperature(gchar *sensor_path, gint id,
 	FILE		*f;
 	gchar		buf[128], units[32];
 	gint		n;
-	gfloat		T, t[5], ibm_acpi_temp[8];
+	gfloat		T, t[5],ibm_acpi_temp[8];
 	gboolean	result = FALSE;
 
 	if (   interface == THERMAL_INTERFACE
@@ -2131,15 +2490,21 @@ gkrellm_sys_sensors_get_temperature(gchar *sensor_path, gint id,
 #endif
 		}
 
-    if (interface == UNINORTH_INTERFACE)
-        {
-        if ((f = fopen(sensor_path, "r")))
-            {
-            fscanf(f, "%f", temp);
-            fclose(f);
-            return TRUE;
-            }
-        }
+	if (interface == UNINORTH_INTERFACE || interface == WINDFARM_INTERFACE)
+		{
+		if ((f = fopen(sensor_path, "r")))
+			{
+			fscanf(f, "%f", temp);
+			fclose(f);
+			return TRUE;
+			}
+		return FALSE;
+		}
+
+#ifdef HAVE_LIBSENSORS
+	if (interface == LIBSENSORS_INTERFACE)
+		return libsensors_get_value(sensor_path, id, iodev, temp);
+#endif
 
 	if ((f = fopen(sensor_path, "r")) == NULL)
 		return FALSE;
@@ -2188,13 +2553,30 @@ gkrellm_sys_sensors_get_fan(gchar *sensor_path, gint id,
 		return result;
 		}
 
-
 	if (interface == MBMON_INTERFACE)
 		{
 		gkrellm_sys_sensors_mbmon_check(FALSE);
 		return gkrellm_sys_sensors_mbmon_get_value(sensor_path, fan);
 		}
 
+	if (interface == WINDFARM_INTERFACE)
+		{
+		f = fopen(sensor_path, "r");
+		if (f)
+			{
+			fscanf(f, "%d", &n);
+			fclose(f);
+			*fan = n;
+			result = TRUE;
+			}
+		return result;
+		}
+
+#ifdef HAVE_LIBSENSORS
+	if (interface == LIBSENSORS_INTERFACE)
+		return libsensors_get_value(sensor_path, id, iodev, fan);
+#endif
+
 	if ((f = fopen(sensor_path, "r")) == NULL)
 		return FALSE;
 	fgets(buf, sizeof(buf), f);
@@ -2215,10 +2597,11 @@ gboolean
 gkrellm_sys_sensors_get_voltage(gchar *sensor_path, gint id,
 		gint iodev, gint interface, gfloat *volt)
 	{
-	FILE	*f;
-	gchar	buf[64];
-	gfloat	V, t[3];
-	gint	n;
+	FILE		*f;
+	gchar		buf[64];
+	gfloat		V, t[3];
+	gint		n;
+	gboolean	result = FALSE;
 
 	if (interface == MBMON_INTERFACE)
 		{
@@ -2226,6 +2609,23 @@ gkrellm_sys_sensors_get_voltage(gchar *sensor_path, gint id,
 		return gkrellm_sys_sensors_mbmon_get_value(sensor_path, volt);
 		}
 
+	if (interface == WINDFARM_INTERFACE)
+		{
+		f = fopen(sensor_path, "r");
+		if (f)
+			{
+			fscanf(f, "%f", volt);
+			fclose(f);
+			result = TRUE;
+			}
+		return result;
+		}
+
+#ifdef HAVE_LIBSENSORS
+	if (interface == LIBSENSORS_INTERFACE)
+		return libsensors_get_value(sensor_path, id, iodev, volt);
+#endif
+
 	if ((f = fopen(sensor_path, "r")) == NULL)
 		return FALSE;
 	fgets(buf, sizeof(buf), f);
@@ -2291,6 +2691,13 @@ get_volt_default(gchar *chip_name, VoltDefault **vdf, gint *vdfsize)
 		*vdf = &voltdefault2[0];
 		*vdfsize = sizeof (voltdefault2) / sizeof (VoltDefault);
 		}
+	else if (   !strncmp(chip_name, "w83627thf", 9)
+		     || !strncmp(chip_name, "w83637hf", 8)
+		    )
+		{
+		*vdf = &voltdefault12[0];
+		*vdfsize = sizeof (voltdefault12) / sizeof (VoltDefault);
+		}
 	else if (!strncmp(chip_name, "w83", 3) && strncmp(chip_name, "w83781", 6))
 		{
 		*vdf = &voltdefault1[0];
@@ -2301,6 +2708,16 @@ get_volt_default(gchar *chip_name, VoltDefault **vdf, gint *vdfsize)
 		*vdf = &voltdefault9[0];
 		*vdfsize = sizeof (voltdefault9) / sizeof (VoltDefault);
 		}
+	else if (!strncmp(chip_name, "abituguru2", 10))
+		{
+		*vdf = &voltdefault10[0];
+		*vdfsize = sizeof (voltdefault10) / sizeof (VoltDefault);
+		}
+	else if (!strncmp(chip_name, "abituguru", 9))
+		{
+		*vdf = &voltdefault11[0];
+		*vdfsize = sizeof (voltdefault11) / sizeof (VoltDefault);
+		}
 	else
 		{
 		*vdf = &voltdefault0[0];
@@ -2343,23 +2760,42 @@ sysfs_get_chip_name(gchar *dir)
 static void
 sysfs_sensors_init(void)
 	{
-	GDir			*dir, *chip_dir;
+	GDir			*dir, *chip_dir, *dirx;
 	VoltDefault		*voltdefault;
 	gint			id = 0;
 	gint			type, voltdefaultsize;
 	gfloat			factor, offset;
 	gchar			*name, *bus_name, *default_label, *vref,
 					*id_name,  *chip_name, *s, *d, *sensor_path;
+	const gchar		*old_bus_name;
+	gchar			*old_id_name, *old_path;
 	gchar			path[256], buf[256];
+	gboolean		using_i2c_dir = FALSE;
+	ConfigMap		*config_map;
 
 	if (!have_sysfs)
 		return;
 
-	if ((dir = g_dir_open(SYSFS_I2C_DIR, 0, NULL)) == NULL)
-		return;
+	if ((dir = g_dir_open(SYSFS_HWMON_DIR, 0, NULL)) == NULL)
+		{
+		/* try again with the sysfs i2c dir for older 2.6 kernels */
+		if ((dir = g_dir_open(SYSFS_I2C_DIR, 0, NULL)) == NULL)
+ 			return;
+		using_i2c_dir = TRUE;
+		gkrellm_sensors_config_migrate_connect(sensors_config_migrate,
+				SENSOR_NAMES_I2C);
+		}
+	else
+		gkrellm_sensors_config_migrate_connect(sensors_config_migrate,
+				SENSOR_NAMES_HWMON);
+
 	while ((bus_name = (gchar *) g_dir_read_name(dir)) != NULL)
 		{
-		snprintf(path, sizeof(path), "%s/%s", SYSFS_I2C_DIR, bus_name);
+		if (using_i2c_dir)
+			snprintf(path, sizeof(path), "%s/%s", SYSFS_I2C_DIR, bus_name);
+		else
+			snprintf(path, sizeof(path), "%s/%s/device",
+					SYSFS_HWMON_DIR, bus_name);
 		if ((chip_dir = g_dir_open(path, 0, NULL)) == NULL)
 			continue;
 		if ((chip_name = sysfs_get_chip_name(path)) == NULL)
@@ -2418,6 +2854,29 @@ sysfs_sensors_init(void)
 			if (_GK.debug_level & DEBUG_SENSORS)
 				printf("%s %s %d %d\n",
 							sensor_path, id_name, id, type);
+
+			if (!using_i2c_dir)
+				{
+				old_path = g_strdup_printf("%s/%s/device/bus/devices",
+						SYSFS_HWMON_DIR, bus_name);
+				if ((dirx = g_dir_open(old_path, 0, NULL)) != NULL)
+					{
+					while ((old_bus_name = g_dir_read_name(dirx)) != NULL)
+						{
+						config_map = g_new0(ConfigMap, 1);
+						config_map->current_name = g_strdup(id_name);
+						old_id_name = g_strdup_printf("%s-%s/%s",
+								chip_name, old_bus_name, buf);
+						config_map->i2c_name = g_strdup(old_id_name);
+						config_map_list =
+								g_list_append(config_map_list, config_map);
+						g_free(old_id_name);
+						}
+					g_dir_close(dirx);
+					}
+				g_free(old_path);
+				}
+
 			g_free(id_name);
 			g_free(sensor_path);
 			}
@@ -2427,22 +2886,40 @@ sysfs_sensors_init(void)
 	g_dir_close(dir);
 	}
 
-  /* Eventually, move this function from sensors.c to here where
-  |  it belongs.
+  /* Remove embedded "-i2c-" or "-isa-" from /proc lm_sensors chip names so
+  |  there can be a chance for config name /proc -> /sysfs compatibility.
+  |  /proc was used in older 2.4 kerneles.
+  |  Munge names like w83627hf-isa-0290 to w83627hf-0-0290
+  |                or w83627hf-i2c-0-0290 to w83627hf-0-0290
+  |  lm_sensor i2c bus address may not be 4 digits, eg: w83782d-i2c-0-2d
+  |  and for that we want: w83782d-0-002d
   */
-extern void		gkrellm_sensors_linux_name_fix(gchar *chip_name);
+void
+sensors_proc_name_fix(gchar *id_name)
+	{
+	gchar	*s;
+	gint	len, bus = 0;
+	guint	addr = 0;
+
+	len = strlen(id_name) + 1;
+	if ((s = strstr(id_name, "-i2c-")) != NULL)
+		{
+		sscanf(s + 5, "%d-%x", &bus, &addr);
+		snprintf(s, len - (s - id_name), "-%d-%04x", bus, addr);
+		}
+	else if ((s = strstr(id_name, "-isa-")) != NULL)
+		{
+		*(s + 1) = '0';
+		memmove(s + 2, s + 4, strlen(s + 4) + 1);
+		}
+	else if ((s = strstr(id_name, "-pci-")) != NULL)
+		{
+		*(s + 1) = '0';
+		memmove(s + 2, s + 4, strlen(s + 4) + 1);
+		}
+	}
+
 
-  /* lm_sensors can have "-isa-" or "-i2c-" embedded in /proc chip names so
-  |  they are of form w83627hf-isa-0290.  Sensors from sysfs are derived from
-  |  a bus directory "0-0290" and "name" file with content like "w83627hf"
-  |  which leads to chip names like "w83627hf-0-0290" without the i2c or
-  |  isa.  To have a chance at config compatibility between the two,
-  |  remove the "i2c" and replace the "isa" with "0" in lm_sensors name
-  |  when generating the id_name.  I don't want to do any munging on the
-  |  sysfs names because I can't guess if the lm_sensors names had "i2c" or
-  |  "isa", and besides, probably sysfs will eventually be more common
-  |  so I'll just make its names the standard now (gkrellm 2.1.20).
-  */
 gboolean
 gkrellm_sys_sensors_init(void)
 	{
@@ -2450,10 +2927,10 @@ gkrellm_sys_sensors_init(void)
 	GDir			*dir, *chip_dir;
 	VoltDefault		*voltdefault;
 	gint			id = 0;
-	gint			type, voltdefaultsize;
+	gint			type, voltdefaultsize, cnt;
 	gfloat			factor, offset;
 	gchar			*name, *chip_name, *fixed_chip_name, *path, *default_label;
-	gchar			*vref, *sensor_path, *sensor_name, id_name[128];
+	gchar			*vref, *sensor_path, *sensor_name, id_name[128], pbuf[128];
 	struct lconv	*lc;
 
 	lc = localeconv();
@@ -2597,6 +3074,126 @@ gkrellm_sys_sensors_init(void)
         g_dir_close(dir);
         }
 
+	/* Windfarm (PowerMac G5, others?)) */
+	cnt = 0;
+	do
+		{
+		snprintf(pbuf, sizeof(pbuf), WINDFARM_DIR, cnt++);
+		if ((dir = g_dir_open(pbuf, 0, NULL)) != NULL)
+			{
+			while ((sensor_name = (gchar *) g_dir_read_name(dir)) != NULL)
+				{
+				sensor_path = g_build_filename(pbuf, sensor_name, NULL);
+				if (strncmp(sensor_name, "cpu-temp-", 9) == 0)
+					{
+					sscanf(sensor_name + 9, "%d", &id);
+					snprintf(id_name, sizeof(id_name), "CPU %d", id);
+					gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE,
+								   sensor_path,
+								   id_name, id, 0,
+								   WINDFARM_INTERFACE,
+								   1.0, 0.0, NULL, id_name);
+					}
+				else if (strcmp(sensor_name, "backside-temp") == 0)
+					{
+					gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE,
+								   sensor_path,
+								   "Backside", 0, 0,
+								   WINDFARM_INTERFACE,
+								   1.0, 0.0, NULL, "Backside");
+					}
+				else if (strcmp(sensor_name, "backside-fan") == 0)
+					{
+					gkrellm_sensors_add_sensor(SENSOR_FAN,
+								   sensor_path,
+								   "Backside", 0, 0,
+								   WINDFARM_INTERFACE,
+								   1.0, 0.0, NULL, "Backside");
+					}
+				else if (strncmp(sensor_name, "cpu-front-fan-", 14) == 0)
+					{
+					sscanf(sensor_name + 14, "%d", &id);
+					snprintf(id_name, sizeof(id_name), "CPU Front %d", id);
+					gkrellm_sensors_add_sensor(SENSOR_FAN,
+								   sensor_path,
+								   id_name, id, 0,
+								   WINDFARM_INTERFACE,
+								   1.0, 0.0, NULL, id_name);
+					}
+				else if (strncmp(sensor_name, "cpu-rear-fan-", 13) == 0)
+					{
+					sscanf(sensor_name + 13, "%d", &id);
+					snprintf(id_name, sizeof(id_name), "CPU Rear %d", id);
+					gkrellm_sensors_add_sensor(SENSOR_FAN,
+								   sensor_path,
+								   id_name, id, 0,
+								   WINDFARM_INTERFACE,
+								   1.0, 0.0, NULL, id_name);
+					}
+				else if (strncmp(sensor_name, "cpu-pump-", 9) == 0)
+					{
+					/* <johill> well, a fan is just an airpump too, right ;) */
+					sscanf(sensor_name + 9, "%d", &id);
+					snprintf(id_name, sizeof(id_name), "CPU Pump %d", id);
+					gkrellm_sensors_add_sensor(SENSOR_FAN,
+								   sensor_path,
+								   id_name, id, 0,
+								   WINDFARM_INTERFACE,
+								   1.0, 0.0, NULL, id_name);
+					}
+				else if (strcmp(sensor_name, "hd-temp") == 0)
+					{
+					gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE,
+								   sensor_path,
+								   "Harddisk", 0, 0,
+								   WINDFARM_INTERFACE,
+								   1.0, 0.0, NULL, "Harddisk");
+					}
+				else if (strcmp(sensor_name, "slots-fan") == 0)
+					{
+					gkrellm_sensors_add_sensor(SENSOR_FAN,
+								   sensor_path,
+								   "Slots", 0, 0,
+								   WINDFARM_INTERFACE,
+								   1.0, 0.0, NULL, "Slots");
+					}
+				else if (strcmp(sensor_name, "drive-bay-fan") == 0)
+					{
+					gkrellm_sensors_add_sensor(SENSOR_FAN,
+								   sensor_path,
+								   "Drive Bay", 0, 0,
+								   WINDFARM_INTERFACE,
+								   1.0, 0.0, NULL, "Drive Bay");
+					}
+				else if (strncmp(sensor_name, "cpu-voltage-", 12) == 0)
+					{
+					sscanf(sensor_name + 12, "%d", &id);
+					snprintf(id_name, sizeof(id_name), "CPU %d", id);
+					gkrellm_sensors_add_sensor(SENSOR_VOLTAGE,
+								   sensor_path,
+								   id_name, id, 0,
+								   WINDFARM_INTERFACE,
+								   1.0, 0.0, NULL, id_name);
+					}
+				g_free(sensor_path);
+				}
+			g_dir_close(dir);
+			}
+		}
+		while (dir != NULL);
+
+#ifdef HAVE_LIBSENSORS
+	if (!_GK.without_libsensors && libsensors_init())
+		{
+		gkrellm_sensors_config_migrate_connect(sensors_config_migrate,
+				SENSOR_NAMES_LIBSENSORS);
+		return TRUE;
+		}
+#else
+	if (_GK.debug_level & DEBUG_SENSORS)
+		printf("libsensors support is not compiled in.\n");
+
+#endif
 
 	if ((dir = g_dir_open(SENSORS_DIR, 0, NULL)) == NULL)
 		{
@@ -2606,8 +3203,8 @@ gkrellm_sys_sensors_init(void)
 	while ((chip_name = (gchar *) g_dir_read_name(dir)) != NULL)
 		{
 		fixed_chip_name = g_strdup(chip_name);
-		gkrellm_sensors_linux_name_fix(fixed_chip_name);
-		
+		sensors_proc_name_fix(fixed_chip_name);
+
 		path = g_build_filename(SENSORS_DIR, chip_name, NULL);
 		chip_dir = g_dir_open(path, 0, NULL);
 		if (!chip_dir)
@@ -2616,7 +3213,7 @@ gkrellm_sys_sensors_init(void)
 			continue;
 			}
 		if (_GK.debug_level & DEBUG_SENSORS)
-				printf("lm_sensors dir: %s\n", path);
+			printf("lm_sensors dir: %s\n", path);
 
 		get_volt_default(chip_name, &voltdefault, &voltdefaultsize);
 		while ((sensor_name = (gchar *) g_dir_read_name(chip_dir)) != NULL)
