@@ -1344,3 +1344,109 @@ void		gkrellm_gtk_alert_button(GtkWidget *box, GtkWidget **button,
 {
     (*(callbacks->gkrellm_gtk_alert_button))(box, button, expand, fill, pad, pack_start, cb_func, data);
 }
+
+      /* Functions new for 2.1.9
+      */
+GkrellmPiximage *gkrellm_piximage_new_from_inline(const guint8 *data,
+						gboolean copy_pixels)
+{
+    return (*(callbacks->gkrellm_piximage_new_from_inline))(data, copy_pixels);
+}
+gboolean    gkrellm_load_piximage_from_inline(gchar *name,
+						const guint8 *data, GkrellmPiximage **image,
+						gchar *subdir, gboolean copy_pixels)
+{
+    return (*(callbacks->gkrellm_load_piximage_from_inline))(name, data, image, subdir, copy_pixels);
+}
+void		gkrellm_alert_commands_config(GkrellmAlert *alert,
+                        gboolean alarm, gboolean warn)
+{
+    (*(callbacks->gkrellm_alert_commands_config))(alert, alarm, warn);
+}
+void		gkrellm_reset_alert_soft(GkrellmAlert *alert)
+{
+    (*(callbacks->gkrellm_reset_alert_soft))(alert);
+}
+
+/* Functions new for 2.1.11
+  */
+void		gkrellm_decal_text_clear(GkrellmDecal *d)
+{
+    (*(callbacks->gkrellm_decal_text_clear))(d);
+}
+void		gkrellm_decal_text_insert(GkrellmDecal *d, gchar *s,
+					GkrellmTextstyle *ts, gint x_off, gint y_off)
+{
+    (*(callbacks->gkrellm_decal_text_insert))(d, s, ts, x_off, y_off);
+}
+GkrellmDecal *gkrellm_create_decal_text_with_height(GkrellmPanel *p,
+					GkrellmTextstyle *ts, GkrellmStyle *style,
+					gint x, gint y, gint w, gint h, gint y_baseline)
+{
+    return (*(callbacks->gkrellm_create_decal_text_with_height))(p, ts, style, x, y, w, h, y_baseline);
+}
+void		gkrellm_chartconfig_callback_block(GkrellmChartconfig *a,
+					gboolean b)
+{
+    (*(callbacks->gkrellm_chartconfig_callback_block))(a, b);
+}
+
+  /* Functions new for 2.1.16
+  */
+void		gkrellm_alert_get_alert_state(GkrellmAlert *alert,
+					gboolean *alarm_state, gboolean *warn_state)
+{
+    (*(callbacks->gkrellm_alert_get_alert_state))(alert, alarm_state, warn_state);
+}
+GkrellmAlertPlugin	*gkrellm_alert_plugin_add(GkrellmMonitor *mon,
+					gchar *name)
+{
+    return (*(callbacks->gkrellm_alert_plugin_add))(mon, name);
+}
+void		gkrellm_alert_plugin_alert_connect(GkrellmAlertPlugin *gap,
+            		void (*alarm_func)(), void (*warn_func)(),
+					void (*update_func)(), void (*check_func)(),
+					void (*destroy_func)())
+{
+    (*(callbacks->gkrellm_alert_plugin_alert_connect))(gap, alarm_func, warn_func, update_func, check_func, destroy_func);
+}
+void		gkrellm_alert_plugin_config_connect(GkrellmAlertPlugin *gap,
+					gchar *tab_name,
+            		void (*config_create_func)(), void (*config_done_func),
+            		void (*config_save_func)(),void (*config_load_func)())
+{
+    (*(callbacks->gkrellm_alert_plugin_config_connect))(gap, tab_name, config_create_func, config_done_func, config_save_func, config_load_func);
+}
+gchar		*gkrellm_alert_plugin_config_get_id_string(GkrellmAlert *alert)
+{
+    return (*(callbacks->gkrellm_alert_plugin_config_get_id_string))(alert);
+}
+void		gkrellm_alert_plugin_alert_attach(GkrellmAlertPlugin *gap,
+            		GkrellmAlert *alert, gpointer data)
+{
+    (*(callbacks->gkrellm_alert_plugin_alert_attach))(gap, alert, data);
+}
+void		gkrellm_alert_plugin_alert_detach(GkrellmAlertPlugin *gap,
+					GkrellmAlert *alert)
+{
+    (*(callbacks->gkrellm_alert_plugin_alert_detach))(gap, alert);
+}
+gpointer	gkrellm_alert_plugin_get_data(GkrellmAlertPlugin *gap,
+					GkrellmAlert *alert)
+{
+    return (*(callbacks->gkrellm_alert_plugin_get_data))(gap, alert);
+}
+void		gkrellm_alert_plugin_command_process(GkrellmAlert *alert,
+					gchar *src, gchar *dst, gint dst_size)
+{
+    (*(callbacks->gkrellm_alert_plugin_command_process))(alert, src, dst, dst_size);
+}
+GtkWidget	*gkrellm_gtk_category_vbox(GtkWidget *box, gchar *category_header,
+        			gint header_pad, gint box_pad, gboolean pack_start)
+{
+    return (*(callbacks->gkrellm_gtk_category_vbox))(box, category_header, header_pad, box_pad, pack_start);
+}
+void		gkrellm_remove_launcher(GkrellmLauncher *launch)
+{
+    (*(callbacks->gkrellm_remove_launcher))(launch);
+}
