@@ -1,7 +1,7 @@
  /* GKrellM
-|  Copyright (C) 1999-2004 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  Windows code: Bill Nalen bill@nalens.com
@@ -1152,7 +1152,8 @@ void gkrellm_sys_disk_read_data(void)
 	for (i = 0; i < numDisks; i++)
 		{
 //    		gkrellm_disk_assign_data_nth(i, diskread[i], diskwrite[i]);
-    	    gkrellm_disk_assign_data_by_device(i, 0, diskread[i], diskwrite[i]);
+    	    gkrellm_disk_assign_data_by_device(i, 0,
+						diskread[i], diskwrite[i], FALSE);
 		}
 	}
 
